import {type GridColDef} from '@mui/x-data-grid'
import {CustomDataGrid} from '../../components/CustomDataGrid'
import {DeleteButton, EditButton, List, ShowButton, useDataGrid} from '@refinedev/mui'
import React from 'react'

import {localeText} from '../../locales/ru/localeText'

export const ArticleList = () => {
  const {dataGridProps} = useDataGrid({
    resource: 'article/',
  })

  const columns = React.useMemo<GridColDef[]>(
    () => [
      {
        field: 'id',
        headerName: 'ID',
        type: 'number',
        minWidth: 70,
        display: 'flex',
        align: 'left',
        headerAlign: 'left',
      },
      {
        field: 'heading',
        headerName: 'Заголовок',
        type: 'string',
        minWidth: 300,
        display: 'flex',
        align: 'left',
        headerAlign: 'left',
        flex: 1,
      },
      // {
      //   field: 'body',
      //   headerName: 'Контент',
      //   type: 'string',
      //   display: 'flex',
      //   align: 'left',
      //   headerAlign: 'left',
      //   flex: 1,
      // },
      {
        field: 'actions',
        headerName: 'Действия',
        align: 'right',
        headerAlign: 'center',
        minWidth: 120,
        display: 'flex',
        sortable: false,
        filterable: false,
        disableColumnMenu: true,
        renderCell: function render({row}) {
          return (
            <>
              <EditButton hideText recordItemId={row.id} />
              <ShowButton hideText recordItemId={row.id} />
              <DeleteButton hideText recordItemId={row.id} />
            </>
          )
        },
      },
    ],
    [],
  )

  return (
    <List>
      <CustomDataGrid {...dataGridProps} columns={columns} localeText={localeText} getRowId={(row: any) => row.id} />
    </List>
  )
}
