import { Media } from "@mt/common-types";
import { ImageMedia } from "./ImageMedia";
import { VideoMedia } from "./VideoMedia";
import { PhotoSphereMedia } from "./PhotoSphereMedia";
import { Object3DMedia } from "./Object3DMedia";
import { memo } from "react";

export const AttractionMedia = memo(
  ({ media }: { media: Media }) => {
    const { type, url, watermarkUrl } = media;

    if (!url) return null;

    switch (type) {
      case "IMAGE":
        return (
          <ImageMedia url={url} alt={media.url} watermarkUrl={watermarkUrl} />
        );
      case "VIDEO":
        return <VideoMedia url={url} watermarkUrl={watermarkUrl} />;
      case "PHOTO_SPHERE":
        return <PhotoSphereMedia url={url} watermarkUrl={watermarkUrl} />;
      case "OBJECT_3D":
        return <Object3DMedia url={url} watermarkUrl={watermarkUrl} />;
      default:
        return null;
    }
  },
  ({ media }, { media: newMedia }) => {
    return (
      media.url === newMedia.url &&
      media.watermarkUrl === newMedia.watermarkUrl &&
      media.type === newMedia.type
    );
  }
);
