import cn from "classnames";
import React, { useEffect, useState } from "react";

import "./AttractionMedia.css";
import ModelViewer from "../../model-viewer/ModelViewer";
import { Icons, useLightboxContext } from "@mt/components";
import { Object3DLightboxData } from "@mt/common-types";

interface Object3DMediaProps {
  url: string;
  watermarkUrl?: string;
}

export const Object3DMedia = ({ url, watermarkUrl }: Object3DMediaProps) => {
  // prettier-ignore
  const { setData, openLightbox } = useLightboxContext<Object3DLightboxData>();
  const [autoRotate, setAutoRotate] = useState(true);

  const handle3DFullscreenOpen = () => {
    setAutoRotate(false);
    setData({
      type: "OBJECT_3D",
      modelUrl: url,
      watermarkUrl,
    });
    openLightbox();
  };

  useEffect(() => {
    setAutoRotate(true);
  }, [url]);

  return (
    <div className="widget-media__wrapper">
      <div
        className={cn("widget-3d-model", {
          "media-with-watermark": watermarkUrl !== null,
        })}
      >
        <ModelViewer key={url} pathToModel={url} autoRotate={autoRotate} />
        {watermarkUrl && (
          <img src={watermarkUrl} alt="Watermark" className="watermark" />
        )}
      </div>

      <Icons.FullscreenIcon
        className="fullscreen-3d-btn"
        onPointerUp={() => handle3DFullscreenOpen()}
      />
    </div>
  );
};
