import cn from "classnames";
import { HTMLAttributes, ReactNode } from "react";

import { StyledDrawer } from "./Drawer.styles";
import { Icons } from "@mt/components";
import { Locale, LocaleSwitcher } from "@mt/i18n";

export interface DrawerProps extends HTMLAttributes<HTMLDivElement> {
  onToggle: (isOpened: boolean) => void;
  isOpen: boolean;
  onHomeBtnClick?: () => void;
  onLocaleChange: (locale: Locale) => void;
  actions?: ReactNode;
}

// TODO: consider refactoring - drawer and controls should be separated
export function Drawer({
  children,
  isOpen,
  onToggle,
  onHomeBtnClick,
  onLocaleChange,
  actions,
  ...props
}: DrawerProps) {
  return (
    <StyledDrawer
      className={cn("g-flex-column", { "nav-widget--opened": isOpen })}
      {...props}
    >
      {children}

      <div className="g-flex actions">
        <div
          className="action-btn toggle-btn"
          onPointerUp={() => onToggle(!isOpen)}
        >
          <Icons.ArrowBtn />
        </div>

        {isOpen && (
          <div className="action-btn" onPointerUp={() => onHomeBtnClick?.()}>
            <Icons.HomeBtn />
          </div>
        )}

        {actions}

        <LocaleSwitcher onLocaleChange={onLocaleChange} />
      </div>
    </StyledDrawer>
  );
}
