import {
  ComposableMap,
  ZoomableGroup,
  ZoomableGroupProps,
} from "react-simple-maps";
import styles from "./MapWidget.module.css";
import { mapCanvasProps, useMapWidgetContext } from "../../MapWidgetContext";
import { useState, FC, ReactNode } from "react";
import { MapContent } from "./MapContent";

// Create wrapper components to handle type issues
const ComposableMapWrapper: FC<any> = (props) => {
  // @ts-ignore - Ignore type issues with the ComposableMap component
  return <ComposableMap {...props} />;
};

const ZoomableGroupWrapper: FC<ZoomableGroupProps> = (props) => {
  // @ts-ignore - Ignore type issues with the ZoomableGroup component
  return <ZoomableGroup {...props} />;
};

// default coordinates for 3a route: 59.943, 30.331
export const MapWidget = () => {
  const { onMapCenterMoved, projection, isDragMode, rotateAngle } =
    useMapWidgetContext();
  const [key, setKey] = useState(42);

  const handleMoveEnd: ZoomableGroupProps["onMoveEnd"] = (e, d3Zoom) => {
    const { PI, cos, sin } = Math;
    const { x, y } = d3Zoom.transform;
    const { width, height } = mapCanvasProps;

    const alpha = (-rotateAngle * PI) / 180;

    const x1 = x * cos(alpha) - y * sin(alpha);
    const y1 = x * sin(alpha) + y * cos(alpha);

    const cX = width / 2 - x1;
    const cY = height / 2 - y1;

    const [lon, lat] = projection.invert?.([cX, cY]) ?? [0, 0];

    onMapCenterMoved({ lon, lat });
    setKey(-key);
  };

  return (
    <ComposableMapWrapper
      projection={projection as any}
      className={styles.mapWidget}
      {...mapCanvasProps}
    >
      <ZoomableGroupWrapper
        key={key}
        center={projection.center()}
        onMoveEnd={handleMoveEnd}
        filterZoomEvent={() => isDragMode}
        minZoom={1}
        maxZoom={1}
      >
        <MapContent />
      </ZoomableGroupWrapper>
    </ComposableMapWrapper>
  );
};
