import { HTMLAttributes, ReactNode, useContext } from 'react';

import { StationOnMap, TransportIcon, useMapWidgetContext } from '@mt/components';
import { OnMapTextAlignment } from '@mt/common-types';
import { LocalizationContext } from '@mt/i18n';

export interface StationLabelContentProps extends HTMLAttributes<HTMLDivElement> {
  station: StationOnMap;
  children?: ReactNode;
}

type TextAlign = Lowercase<OnMapTextAlignment>;

export const StationLabelContent = ({
  station,
  children,
  className = '',
}: StationLabelContentProps) => {
  const { locale } = useContext(LocalizationContext);
  const { rotateAngle } = useMapWidgetContext();

  const { pointOnMap, labelAlignment, iconUrl, shortName, name, transferStationInfos } = station;

  return (
    <div
      id={`${pointOnMap.lat}:${pointOnMap.lon}`}
      className={`track-station__wrapper ${className}`}
      style={{
        textAlign: labelAlignment as TextAlign,
        // Inverse angle to compensate map rotation
        transform: `rotate(${-rotateAngle}deg)`,
      }}
    >
      <div className="track-station__label">
        {iconUrl && <img className="track-station__icon" src={iconUrl} />}
        {(shortName ?? name).ru}
      </div>

      <div className="track-station__transfers-wrapper">
        {transferStationInfos.map((transfer) => (
          <div className="track-station__label" key={transfer.name.ru}>
            <TransportIcon type={transfer.type} className="transport-icon" />
            {transfer.name.ru}
          </div>
        ))}
      </div>

      <div className="track-station__label-locale">
        {locale === 'zh' ? (shortName ?? name).zh : (shortName ?? name).en}
      </div>

      {children}
    </div>
  );
};
