import { useState } from 'react';
import Draggable, { DraggableData, DraggableEvent } from 'react-draggable';
import { ButtonGroup, IconButton } from '@mui/material';
import AlignHorizontalLeftRoundedIcon from '@mui/icons-material/AlignHorizontalLeftRounded';
import AlignHorizontalCenterRoundedIcon from '@mui/icons-material/AlignHorizontalCenterRounded';
import AlignHorizontalRightRoundedIcon from '@mui/icons-material/AlignHorizontalRightRounded';

// TODO: resolve circular deps
import { OnMapOffset, OnMapTextAlignment } from '@mt/common-types';
import { useMapWidgetContext } from '@mt/components';
import { StationLabelContent, StationLabelContentProps } from './StationLabelContent';

const CONTAINER_WIDTH = 1343;
const SVG_WIDTH = 500;

export const StationLabelEdit = ({ station }: StationLabelContentProps) => {
  const { onStationUpdate } = useMapWidgetContext();
  const { id, labelOffset } = station;

  const [calculatedOffset] = useState<OnMapOffset>(labelOffset);
  const [dragStartPoint, setDragStartPoint] = useState<OnMapOffset>({ x: -1, y: -1 });

  const onDragStart = () => setDragStartPoint(calculatedOffset);

  const onDragStop = (e: DraggableEvent, { lastX, lastY }: DraggableData) => {
    const labelOffset = {
      x: dragStartPoint.x + lastX,
      y: dragStartPoint.y + lastY,
    };

    onStationUpdate(id, { labelOffset });
  };

  const setAlignment = (labelAlignment: OnMapTextAlignment): void =>
    onStationUpdate(id, { labelAlignment });

  return (
    <Draggable
      onStart={onDragStart}
      onStop={onDragStop}
      scale={CONTAINER_WIDTH / SVG_WIDTH}
      positionOffset={calculatedOffset}
    >
      <foreignObject className="track-station">
        <StationLabelContent station={station} className="editable">
          <ButtonGroup size="small" className="align-btns-group">
            <IconButton size="small" onClick={() => setAlignment('LEFT')}>
              <AlignHorizontalLeftRoundedIcon />
            </IconButton>

            <IconButton size="small" onClick={() => setAlignment('CENTER')}>
              <AlignHorizontalCenterRoundedIcon />
            </IconButton>

            <IconButton size="small" onClick={() => setAlignment('RIGHT')}>
              <AlignHorizontalRightRoundedIcon />
            </IconButton>
          </ButtonGroup>
        </StationLabelContent>
      </foreignObject>
    </Draggable>
  );
};
