import { Marker } from "react-simple-maps";
// TODO: resolve circular deps
import type { uuid } from "@mt/common-types";

import { getMapPoint } from "../../utils";

import "./TrackStations.css";
import { StationLabelEdit } from "./StationLabelEdit";
import { useMapWidgetContext } from "../../MapWidgetContext";
import { StationLabel } from "./StationLabel";

const colors = {
  black: "#000000",
  red: "#ed1c24",
  grey: "#cccccc",
  yellow: "#fcd500",
};

export const TrackStations = () => {
  const {
    stations,
    currentStation,
    passedTrackIndex,
    isOnStation,
    isEditMode,
  } = useMapWidgetContext();
  const isTerminalStation = (index: number) =>
    index === 0 || index === stations.length - 1;

  const getStationFill = (
    id: uuid,
    trackIndex: number,
    index: number
  ): string => {
    if (isOnStation && currentStation?.id === id) {
      return colors.yellow;
    }

    if (isTerminalStation(index)) {
      return colors.black;
    }

    return trackIndex <= passedTrackIndex ? colors.red : colors.grey;
  };

  const getStationStroke = (index: number) => {
    if (index === 0) return colors.red;
    if (index === stations.length - 1) return colors.grey;
    return colors.black;
  };

  return (
    <>
      {stations.map((it, index) => (
        <Marker key={it.id} coordinates={getMapPoint(it.pointOnMap)}>
          <circle
            fill={getStationFill(it.id, it.pointOnMap.trackIndex, index)}
            stroke={getStationStroke(index)}
            r={3.5}
            strokeWidth={isTerminalStation(index) ? 2 : 1.5}
          />
          {isEditMode ? (
            <StationLabelEdit station={it} />
          ) : (
            <StationLabel station={it} />
          )}
        </Marker>
      ))}
    </>
  );
};
