import { useEffect, useState } from "react";
import { getIntersection, getIntersectionArea } from "../../utils";
import { Marker, Point } from "react-simple-maps";
import { Coordinates } from "@mt/common-types";
import cn from "classnames";
import styles from "./TramMarker.module.css";
import { Icons, useMapWidgetContext } from "@mt/components";

interface TramMarkerProps {
  coordinates: Point;
  nextStopPoint: Coordinates;
}

export const TramMarker = ({ coordinates, nextStopPoint }: TramMarkerProps) => {
  const [flipped, setFlipped] = useState(false);

  const { rotateAngle } = useMapWidgetContext();

  useEffect(() => {
    const tramRect = document
      .getElementById("tram-marker")
      ?.getBoundingClientRect();
    const nextStopRect = document
      .getElementById(`${nextStopPoint.lat}:${nextStopPoint.lon}`)
      ?.getBoundingClientRect();

    if (tramRect && nextStopRect) {
      // prettier-ignore
      const hasIntersection = getIntersection(tramRect, nextStopRect) !== null;
      const intersectionArea = getIntersectionArea(tramRect, nextStopRect);

      if (hasIntersection && intersectionArea > 150) {
        setFlipped((isFlipped) => !isFlipped);
      }
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [coordinates]);

  return (
    <Marker coordinates={coordinates} id="tram-marker">
      <foreignObject
        className={cn(styles.iconContainer, { [styles.flipped]: flipped })}
      >
        <Icons.TramMarkerIcon
          className={`${styles.icon} g-transform-origin__center`}
          // Inverse angle to compensate map rotation
          style={{ transform: `rotate(${-rotateAngle}deg)` }}
        />
      </foreignObject>
    </Marker>
  );
};
