import { useEffect, useState } from "react";
import { StationOnMap } from "../map-widget.interface";
import { getDistance } from "../utils";
import { Coordinates } from "@mt/common-types";

const ZOOM_DISTANCE = 100;
const ON_STATION_DISTANCE = 15;

export function useNearStation(
  currentPosition: Coordinates | null,
  stations: StationOnMap[],
  passedTrackIndex: number
) {
  const [nextStation, setNextStation] = useState<StationOnMap | null>(null);
  const [currentStation, setCurrentStation] = useState<StationOnMap | null>(
    null
  );
  const [isOnStation, setIsOnStation] = useState<boolean>(false);

  useEffect(() => {
    if (!currentPosition) {
      return;
    }

    const nextStationIndex = stations.findIndex(
      ({ pointOnMap }) => pointOnMap.trackIndex > passedTrackIndex
    );

    const nextStation = stations[nextStationIndex] ?? null;
    const prevStation = stations[nextStationIndex - 1] ?? null;

    const distanceToNext = nextStation
      ? getDistance(currentPosition, nextStation.pointOnMap)
      : ZOOM_DISTANCE + 1;

    setNextStation(nextStation);

    if (distanceToNext <= ZOOM_DISTANCE) {
      setCurrentStation(nextStation);
      setIsOnStation(distanceToNext <= ON_STATION_DISTANCE);

      return;
    }

    const distanceToPrev = prevStation
      ? getDistance(currentPosition, prevStation.pointOnMap)
      : ZOOM_DISTANCE + 1;

    if (distanceToPrev <= ZOOM_DISTANCE) {
      setCurrentStation(prevStation);
      setIsOnStation(distanceToPrev <= ON_STATION_DISTANCE);

      return;
    }

    setCurrentStation(null);
    setIsOnStation(false);
  }, [currentPosition, stations, passedTrackIndex]);

  return { currentStation, nextStation, isOnStation };
}
