import { Coordinates, SetState, uuid } from "@mt/common-types";
import { MapData, StationOnMap } from "@mt/components";

import { UseFormReturn } from "react-hook-form";
import { RouteStation } from "@mt/common-types";
import { GeoProjection } from "d3-geo";

export interface MapWidgetContextType {
  // External data
  track: MapData["trackPoints"] | null;
  stations: MapData["stationsOnMap"];
  attractionGroups: MapData["touristAttractionGroupsOnMap"];
  rotateAngle: MapData["mapRotateAngle"];
  center: Coordinates;
  projection: GeoProjection;
  currentPosition: Coordinates | null;
  middleTrackCoordinates: Coordinates | null;
  passedTrackIndex: number;
  currentStation: StationOnMap | null;
  nextStation: StationOnMap | null;
  isOnStation: boolean;

  // Calculated data
  setCurrentPosition: SetState<Coordinates | null>;

  isDragMode: boolean;

  setIsDragMode: SetState<boolean>;
  isEditMode: boolean;
  setIsEditMode: SetState<boolean>;

  onMapDataFetched: (payload: MapData) => void;
  settingsForm: UseFormReturn<MapSettings>;
  onSettingsFormChange: () => void;
  onMapCenterMoved: (center: Coordinates) => void;
  onStationUpdate: (
    stationId: uuid,
    data: Partial<Pick<StationOnMap, "labelAlignment" | "labelOffset">>
  ) => void;
  getUpdatedStations: () => Partial<RouteStation>;
  isMapDataChanged: boolean;
}

export interface MapSettings {
  rotateAngle: number;
  fullScale: number;
  zoomedScale: number;
  center: Coordinates;
  currentStationId?: string;
}
