interface Rectangle {
  left: number;
  top: number;
  right: number;
  bottom: number;
}

export function getIntersection(rect1: Rectangle, rect2: Rectangle): Rectangle | null {
  const left = Math.max(rect1.left, rect2.left);
  const top = Math.max(rect1.top, rect2.top);
  const right = Math.min(rect1.right, rect2.right);
  const bottom = Math.min(rect1.bottom, rect2.bottom);

  if (left < right && top < bottom) {
    return { left, top, right, bottom };
  }

  return null;
}

export function getIntersectionArea(rect1: Rectangle, rect2: Rectangle): number {
  const intersection = getIntersection(rect1, rect2);
  if (intersection === null) {
    return 0;
  }

  const width = intersection.right - intersection.left;
  const height = intersection.bottom - intersection.top;
  return width * height;
}
