import React, { HTMLAttributes, useContext, useEffect, useRef } from "react";
import { LocalizationContext, LocalizedString } from "@mt/i18n";

import styles from "./RouteInfoWidget.module.css";
import cn from "classnames";

export interface RouteInfoData {
  routeNumber: string;
  firstStationName: LocalizedString;
  lastStationName: LocalizedString;
}
interface RouteInfoWidgetProps extends HTMLAttributes<HTMLDivElement> {
  routeInfo?: RouteInfoData;
}

export function RouteInfoWidget({
  routeInfo,
  className,
  ...props
}: RouteInfoWidgetProps) {
  const contentContainerRef = useRef<HTMLDivElement>(null);
  const titleRefs = useRef<Array<HTMLSpanElement>>([]);

  const { locale } = useContext(LocalizationContext);

  useEffect(() => {
    if (!routeInfo?.firstStationName || !routeInfo?.lastStationName) {
      return;
    }

    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
    const container = contentContainerRef.current!;
    const containerWidth = container.offsetWidth;

    titleRefs.current.forEach((title) => {
      const titleWidth = title.offsetWidth;
      const paddingWidth = 8 * 2;

      if (titleWidth + paddingWidth > containerWidth) {
        title.classList.add(styles.crawlLine);
      } else {
        title.classList.remove(styles.crawlLine);
      }
    });
  }, [routeInfo, titleRefs, contentContainerRef]);

  return (
    <div className={cn(styles.root, className)} {...props}>
      <div className={styles.number}>{routeInfo?.routeNumber || "--"}</div>

      {routeInfo ? (
        <div className={styles.content} ref={contentContainerRef}>
          <div className={cn(styles.title, styles.titleStart)}>
            <span ref={(ref) => (titleRefs.current[0] = ref!)}>
              {routeInfo.firstStationName.ru}
            </span>
          </div>
          <div className={cn(styles.title, styles.titleEnd)}>
            <span ref={(ref) => (titleRefs.current[1] = ref!)}>
              {routeInfo.lastStationName.ru}
            </span>
          </div>
          <div className={cn(styles.title, styles.titleTranslation)}>
            <span ref={(ref) => (titleRefs.current[2] = ref!)}>
              {locale === "zh"
                ? `${routeInfo.firstStationName.zh} – ${routeInfo.lastStationName.zh}`
                : `${routeInfo.firstStationName.en} – ${routeInfo.lastStationName.en}`}
            </span>
          </div>
        </div>
      ) : null}
    </div>
  );
}
