import styled from '@emotion/styled';
import { HTMLAttributes } from 'react';
import { WeatherWidgetRight } from './weather-widget-right';
import { WeatherWidgetTime } from './weather-widget-time';
import { WeatherWidgetToday } from './weather-widget-today';
import { WeatherWidgetData } from './weather.interface';
import { WEATHER_DEFAULTS } from './weather.constant';

const StyledWeatherWidget = styled.div`
  width: 225px;
  height: 260px;
  padding: 8px;

  background: linear-gradient(180deg, rgba(255, 255, 255, 0.2) 0%, rgba(255, 255, 255, 0) 100%),
    rgba(179, 165, 152, 0.4);
  box-shadow: inset 4px 4px 12px rgba(255, 255, 255, 0.12);
  backdrop-filter: blur(6px);
  color: #fff;
  font-weight: 400;

  border-radius: 10px;
`;

interface Props extends HTMLAttributes<HTMLDivElement> {
  weatherData?: WeatherWidgetData;
}

export function WeatherWidget({ weatherData = WEATHER_DEFAULTS, ...props }: Props) {
  const { weatherInfo, forecasts } = weatherData;

  return (
    <StyledWeatherWidget {...props}>
      <WeatherWidgetTime />
      <div
        style={{
          display: 'flex',
          justifyContent: 'space-between',
          marginTop: '8px',
        }}
      >
        <WeatherWidgetToday {...weatherInfo} />
        <WeatherWidgetRight weatherInfo={weatherInfo} forecasts={forecasts} />
      </div>
    </StyledWeatherWidget>
  );
}
