import React, { createContext, useState, useContext, ReactNode } from 'react';

interface LightboxContextType<T> {
  data: T;
  setData: (data: T) => void;
  lightboxActive: boolean;
  openLightbox: () => void;
  closeLightbox: () => void;
}

// prettier-ignore
export const LightboxContext = createContext<LightboxContextType<any> | undefined>(undefined);

export const LightboxProvider = ({ children }: { children: ReactNode }) => {
  const [data, setData] = useState(null);
  const [lightboxActive, setLightboxActive] = useState(false);

  const openLightbox = () => {
    setLightboxActive(true);
  };

  const closeLightbox = () => {
    setLightboxActive(false);
  };

  const contextValue = {
    data,
    setData,
    lightboxActive,
    openLightbox,
    closeLightbox,
  };

  return (
    <LightboxContext.Provider value={contextValue}>
      {children}
    </LightboxContext.Provider>
  );
};

export const useLightboxContext = function <T>(): LightboxContextType<T> {
  const context = useContext(LightboxContext);

  if (!context) {
    throw new Error(
      'useLightboxContext must be used within a LightboxProvider'
    );
  }

  return context;
};
