import { useGetRouteData } from "../hooks/useGetRouteData";
import { useUpdateRouteData } from "../hooks/useUpdateRouteData";
import {
  MapSettings,
  MapWidget,
  RouteInfoData,
  useMapWidgetContext,
} from "@mt/components";
import { SettingsPanel } from "./SettingsPanel/SettingsPanel";
import { useEffect, useState } from "react";
import { RoutePreviewDashboard } from "./RoutePreviewDashboard/RoutePreviewDashboard";
import { LocalizedStringDefaults } from "@mt/common-types";
import { useParams } from "react-router";

export const RoutePreviewContainer = () => {
  const { routeId } = useParams();
  const { routeData, mappedData, isLoading, isError } =
    useGetRouteData(routeId);
  const updateRouteView = useUpdateRouteData(routeId, routeData);
  const [routeInfo, setRouteInfo] = useState<RouteInfoData>();

  const {
    onMapDataFetched,
    setCurrentPosition,
    middleTrackCoordinates,
    setIsEditMode,
    getUpdatedStations,
  } = useMapWidgetContext();

  const handleSubmit = (mapSettings: MapSettings) => {
    updateRouteView(mapSettings, getUpdatedStations());
  };

  useEffect(() => {
    if (!mappedData) {
      return;
    }

    onMapDataFetched(mappedData);
    setCurrentPosition(middleTrackCoordinates);
    setIsEditMode(true);

    setRouteInfo({
      routeNumber: routeData?.number ?? "",
      firstStationName:
        mappedData.stationsOnMap.at(0)?.shortName ?? LocalizedStringDefaults,
      lastStationName:
        mappedData.stationsOnMap.at(-1)?.shortName ?? LocalizedStringDefaults,
    });
  }, [mappedData, middleTrackCoordinates]);

  if (isLoading) {
    return (
      <div
        className="g-flex-column g-flex--align-center g-flex--justify-center"
        style={{ height: "1000px" }}
      >
        Загрузка...
      </div>
    );
  }

  if (isError) {
    return (
      <div
        className="g-flex-column g-flex--align-center g-flex--justify-center"
        style={{ height: "1000px" }}
      >
        Ошибка получения данных
      </div>
    );
  }

  if (mappedData) {
    return (
      <RoutePreviewDashboard routeInfo={routeInfo}>
        <MapWidget />
        {/* <SettingsPanel onSubmit={handleSubmit} /> */}
      </RoutePreviewDashboard>
    );
  }
};
