import {
  Drawer,
  Icons,
  RouteInfoData,
  RouteInfoWidget,
  WeatherWidget,
} from "@mt/components";
import { HTMLAttributes, useContext, useState } from "react";
import cn from "classnames";
import { LocalizationContext } from "@mt/i18n";
import styles from "./RoutePreviewDashboard.module.css";

interface Props extends HTMLAttributes<HTMLDivElement> {
  routeInfo: RouteInfoData;
}

export const RoutePreviewDashboard = ({ children, routeInfo }: Props) => {
  const { setLocale } = useContext(LocalizationContext);
  const [openNav, setOpenNav] = useState(false);
  const [openTransfers, setOpenTransfer] = useState(false);

  return (
    <div className={styles.root}>
      <Drawer
        isOpen={openNav}
        onToggle={setOpenNav}
        onLocaleChange={setLocale}
      />

      <div className={cn(styles.container, { [styles.pushed]: openNav })}>
        <div className={styles.leftTopWrapper}>
          <RouteInfoWidget
            className={styles.routeNumber}
            routeInfo={routeInfo}
          />
          <WeatherWidget className={styles.weatherWidget} />
        </div>

        {children}

        <div className={styles.transferPlaceholder}>
          <Icons.InfoBtn
            className={styles.toggleTransferBtn}
            onClick={() => setOpenTransfer(!openTransfers)}
          />

          {openTransfers ? <div className={styles.transferPopup} /> : null}
        </div>
      </div>

      <div className={styles.rightSidebar} />
    </div>
  );
};
