import cn from 'classnames';
import SettingsIcon from '@mui/icons-material/Settings';
import { Button, FormControlLabel, Switch } from '@mui/material';
import { FormProvider } from 'react-hook-form';
import { useState } from 'react';

import { useMapWidgetContext, MapSettings } from '@mt/components';
import { CoordinateField, ScaleField, RotationField, StationSelectField } from './settigs-fields';
import styles from './SettingsPanel.module.css';
import { useToggleScrollable } from '@mt/utils';

interface Props {
  onSubmit?: (data: MapSettings) => void;
}

export const SettingsPanel = ({ onSubmit }: Props) => {
  const [isOpened, setOpened] = useState(true);
  const { enableScroll, disableScroll } = useToggleScrollable();

  const {
    settingsForm,
    onSettingsFormChange,
    stations,
    isDragMode,
    setIsDragMode,
    isMapDataChanged,
  } = useMapWidgetContext();

  const handleGoBack = () => {
    if (
      isMapDataChanged &&
      !window.confirm('Изменения не сохранены! Вы уверены, что хотите покинуть страницу?')
    ) {
      return;
    }

    window.history.back();
  };

  return (
    <FormProvider {...settingsForm}>
      <form
        className={cn('g-flex', styles.root, { [styles.rootOpened]: isOpened })}
        onChange={() => onSettingsFormChange()}
        onSubmit={settingsForm.handleSubmit(onSubmit)}
      >
        <SettingsIcon
          className={styles.togglePanelBtn}
          fontSize="large"
          onClick={() => setOpened(!isOpened)}
        />

        <div className="g-flex-column g-flex__item">
          <RotationField
            name="rotateAngle"
            label="Угол поворота карты"
            onFocus={disableScroll}
            onBlur={enableScroll}
          />

          <CoordinateField name="center" label="Координаты центра" />

          <FormControlLabel
            label="Включите для изменения центра карты с помощью мышки"
            control={
              <Switch checked={isDragMode} onChange={() => setIsDragMode((isDrag) => !isDrag)} />
            }
          />

          <ScaleField
            name="fullScale"
            label="Масштаб 1"
            onFocus={disableScroll}
            onBlur={enableScroll}
          />

          <StationSelectField
            name="currentStationId"
            label="Выберете остановку"
            hint="Для настройки масштаба при приближении к остановкам"
            stations={stations}
            onOpen={disableScroll}
            onClose={enableScroll}
            onChange={() => onSettingsFormChange()}
          />

          <ScaleField
            name="zoomedScale"
            label="Масштаб 2"
            onFocus={disableScroll}
            onBlur={enableScroll}
          />

          <Button type="submit" disabled={!isMapDataChanged}>
            Сохранить изменения
          </Button>

          <Button type="button" onClick={handleGoBack}>
            Назад
          </Button>
        </div>
      </form>
    </FormProvider>
  );
};
