import { Controller, useFormContext } from 'react-hook-form';
import { TextField } from '@mui/material';
import { useCallback } from 'react';
import { FieldProps } from './field-props.interface';
import { TextFieldProps } from '@mui/material/TextField/TextField';

function isValidNumberInRange(value: string | number) {
  const numberValue = Number(value);

  // Check if the value is a valid number, not NaN, within the range of -360 to 360,
  // and disallow leading zeros (except for the value "0")
  return (
    !isNaN(numberValue) &&
    /^-?(0|[1-9]\d*)$/.test(value.toString()) &&
    numberValue >= -360 &&
    numberValue <= 360
  );
}

export const RotationField = ({ name, label, hint, ...props }: FieldProps & TextFieldProps) => {
  const { control, getFieldState, setError, clearErrors } = useFormContext();

  const handleChange = useCallback(
    ({ target }, field) => {
      const { value } = target;

      let newValue: string | number = value;

      if (isValidNumberInRange(value)) {
        newValue = Number(value);
        clearErrors(field.name);
      } else {
        setError(field.name, {
          message: 'Неверный формат. Значение должно быть числом от -360 до 360',
        });
      }

      return field.onChange(newValue);
    },
    [clearErrors, setError]
  );

  return (
    <Controller
      name={name}
      control={control}
      render={({ field }) => (
        <TextField
          type="number"
          label={label}
          inputProps={{ min: -360, max: 360 }}
          value={field.value}
          onChange={(e) => handleChange(e, field)}
          error={getFieldState(field.name).invalid}
          helperText={getFieldState(field.name).error?.message || hint || ''}
          {...props}
        />
      )}
    />
  );
};
