import { TextField } from '@mui/material';
import { Controller, useFormContext } from 'react-hook-form';
import { useCallback } from 'react';
import { FieldProps } from './field-props.interface';
import { TextFieldProps } from '@mui/material/TextField/TextField';

const SCALE_PATTERN = /^[1-9]\d*$/;

export const ScaleField = ({ label, name, hint, ...props }: FieldProps & TextFieldProps) => {
  const { control, getFieldState, setError, clearErrors } = useFormContext();

  const handleChange = useCallback(
    ({ target }, field) => {
      const { value } = target;

      let newValue: string | number = value;

      if (SCALE_PATTERN.test(value)) {
        newValue = Number(value);
        clearErrors(field.name);
      } else {
        setError(field.name, {
          message: 'Неверный формат. Масштаб должен быть положительным числом',
        });
      }

      return field.onChange(newValue);
    },
    [clearErrors, setError]
  );

  return (
    <Controller
      control={control}
      name={name}
      render={({ field }) => (
        <TextField
          type="number"
          label={label}
          inputProps={{ step: 1000, min: 0 }}
          value={field.value}
          onChange={(e) => handleChange(e, field)}
          error={getFieldState(field.name).invalid}
          helperText={getFieldState(field.name).error?.message || hint || ''}
          {...props}
        />
      )}
    />
  );
};
