import {
  FormControl,
  FormHelperText,
  InputLabel,
  MenuItem,
  Select,
  SelectChangeEvent,
} from '@mui/material';
import { StationOnMap } from '@mt/components';
import { useId } from 'react';
import { Controller, useFormContext } from 'react-hook-form';
import { FieldProps } from './field-props.interface';

interface StationSelectFieldProps extends FieldProps {
  onChange: () => void;
  onOpen?: () => void;
  onClose?: () => void;
  stations: StationOnMap[];
}

export const StationSelectField = ({
  name,
  onChange,
  stations,
  label,
  hint,
  ...selectProps
}: StationSelectFieldProps) => {
  const labelId = useId();
  const { control } = useFormContext();

  const handleChange = ({ target: { value } }: SelectChangeEvent, field) => {
    field.onChange(value);
    onChange();
  };

  return (
    <Controller
      control={control}
      name={name}
      defaultValue=""
      render={({ field }) => (
        <FormControl>
          <InputLabel id={labelId}>{label}</InputLabel>
          <Select
            labelId={labelId}
            value={field.value}
            onChange={(e) => handleChange(e, field)}
            {...selectProps}
          >
            <MenuItem value="">Станция не выбрана</MenuItem>

            {stations.map((station) => (
              <MenuItem value={station.id} key={station.id}>
                {station.name.ru}
              </MenuItem>
            ))}
          </Select>

          <FormHelperText>{hint}</FormHelperText>
        </FormControl>
      )}
    />
  );
};
