import { MapData } from "@mt/components";
import { useEffect, useState } from "react";
import { mapRouteFromApi } from "../mappers/mapRouteFromApi";
import { useOn, Station, useOne, useMany } from "@refinedev/core";
import { Route } from "@mt/common-types";

export const useGetRouteData = (routeId: string) => {
  const [mappedData, setMappedData] = useState<MapData | null>(null);
  const [error, setError] = useState<string | null>(null); // Handle error state

  // Fetch route data
  const {
    data: routeData,
    isSuccess,
    isError,
    isLoading,
  } = useOne<Route>("routes", { id: routeId });

  const { data: stations } = useMany<Station>("stations", {
    ids: routeData?.stations.flatMap(({ stationId, transferStations }) => {
      const transferIds = transferStations
        .filter(({ isShowOnMap }) => isShowOnMap)
        .map(({ stationId: id }) => id);
      return [stationId, ...transferIds];
    }),
  });
  // Handle loading state and errors
  useEffect(() => {
    if (isLoading || stationsLoading) {
      setError(null); // Reset error during loading
      return;
    }

    if (isError || stationsError) {
      setError("Failed to fetch route or station data.");
      return;
    }

    if (!routeData || !stations) {
      return;
    }

    try {
      const data = mapRouteFromApi(routeData, stations);
      setMappedData(data); // Set the mapped data
    } catch (err) {
      setError("Error mapping the route data.");
    }
  }, [routeData, stations, isLoading, stationsLoading, isError, stationsError]);

  return {
    routeData,
    mappedData,
    isLoading: isLoading || stationsLoading, // Combine loading states
    isError: isError || stationsError, // Combine error states
    error, // Provide the error message
  };
};
