import React, { useCallback, useState } from "react";
// TODO: resolve circular deps (probably we should move icons to a separate lib)
import { Icons } from "@mt/components";
import { Locale, localesMap } from "../i18n.interface";
import "./LocaleSwitcher.css";

interface LocaleSwitcherProps {
  onLocaleChange: (locale: Locale) => void;
}

export const LocaleSwitcher = ({ onLocaleChange }: LocaleSwitcherProps) => {
  const [isOpen, setIsOpen] = useState(false);
  const [selectedLocale, setSelectedLocale] = useState<Locale>("ru");

  const handleLocaleChange = useCallback(
    (locale: Locale) => {
      setSelectedLocale(locale);
      setIsOpen(false);
      onLocaleChange(locale);
    },
    [isOpen]
  );

  return (
    <div className="locale-switcher">
      {!isOpen ? (
        <button
          className="locale-switcher__button"
          onPointerUp={() => setIsOpen(!isOpen)}
        >
          <Icons.I18NIcon />
        </button>
      ) : (
        <div className="locale-switcher__options">
          {Object.entries(localesMap).map(([label, locale]) => (
            <button
              key={locale}
              className={`locale-switcher__option ${
                selectedLocale === locale ? "selected" : ""
              }`}
              onPointerUp={() => handleLocaleChange(locale)}
            >
              {label}
            </button>
          ))}
        </div>
      )}
    </div>
  );
};
