import React, { createContext, ReactNode, useState } from 'react';
import { IntlProvider } from 'react-intl';
import { Locale } from './i18n.interface';
import { getLanguage } from './language-loader';

export const LocalizationContext = createContext<{
  locale: Locale;
  setLocale: (locale: Locale) => void;
}>({
  locale: 'ru',
  // eslint-disable-next-line @typescript-eslint/no-empty-function
  setLocale: (locale: Locale) => {},
});

export const LocalizationProvider = ({ children }: { children: ReactNode }) => {
  const [locale, setLocale] = useState<Locale>('ru');

  return (
    <LocalizationContext.Provider value={{ locale, setLocale }}>
      <IntlProvider locale={locale} messages={getLanguage(locale)}>
        {children}
      </IntlProvider>
    </LocalizationContext.Provider>
  );
};
