import { useContext } from 'react';
import { LocalizationContext } from './localization-context';
import { Locale, LocalizedString } from './i18n.interface';

export type LocalizeTextFn = (content: LocalizedString | undefined) => string;

export function useServerLocalization() {
  const { locale } = useContext(LocalizationContext);

  const localizeText: LocalizeTextFn = (content) => {
    if (content && typeof content === 'object' && locale in content) {
      return content[locale as Locale];
    } else {
      return '';
    }
  };

  return localizeText;
}
