import {
  ArticleBase,
  Coordinates,
  StationOnMap,
  TransportType,
} from "@mt/common-types";
import { LocalizedString } from "@mt/i18n";
import { AttractionBase } from "./attraction.interface";
import { StationBase } from "./station.interface";
import { OnMapTextAlignment } from "./on-map.type";
import { OnMapOffset } from "./on-map.type";
import { uuid } from "./uuid.type";
import { AttractionGroupIconSizeType } from "./attraction-group-icon-size.type";
import { Track } from "./track.type";

export interface Station extends Omit<StationOnMap, "coordinates"> {
  pointOnMap: Coordinates;
}

export interface Article extends Omit<ArticleBase, "name"> {
  title: LocalizedString;
}

export interface Transfer {
  type: TransportType;
  name: LocalizedString;
}

export interface Article extends ArticleBase {
  isHidden: boolean;
}

export interface Attraction extends AttractionBase {
  articles: Article[];
  cityId: string;
}

export interface Station extends StationBase {
  coordinates: Coordinates;
  cityId: string;
}

export interface City {
  id: string;
  title: string;
  version: number;
  isDefault: boolean;
}

export interface RouteStation {
  stationId: uuid;
  textAlignment: OnMapTextAlignment;
  mapOffsets: OnMapOffset;
  transferStations: TransferStation[];
  transferRoutes: TransferRoute[];
}

export interface TransferStation {
  stationId: uuid;
  isShowOnMap: boolean;
  ordinal: number;
}

export interface TransferRoute {
  routeNumber: string;
  // TODO: check if they match (transportType & routeType) and probably create the copy of it to avoid naming confusion
  routeTypeId: TransportType;
  ordinal: number;
}

export interface RouteAttraction {
  attractionId: uuid;
}

export interface RouteAttractionGrouping {
  id: uuid; // FE virtual field
  attractionIds: uuid[];
  iconSize: AttractionGroupIconSizeType;
  coordinates: Coordinates;
}

export interface RouteAttractionToStationBinding {
  stationId: uuid;
  nearbyAttractionIds: uuid[];
}

export interface RouteStationToAttractionBinding {
  attractionId: uuid;
  nearbyStationIds: uuid[];
}

export interface Route {
  id: string;
  cityId: string;
  number: string;
  speakingCityNumber: number;
  name: LocalizedString;
  generalInfo: {
    track: Track;
    // TODO: discuss and rename (?)
    centerCoordinates: Coordinates;
    scale1: number;
    scale2: number;
    rotate: number;
  };
  stations?: RouteStation[];
  attractions?: RouteAttraction[];
  attractionGroupings: RouteAttractionGrouping[];
  attractionToStationBindings: RouteAttractionToStationBinding[];
  stationToAttractionBindings: RouteStationToAttractionBinding[];
}

export type USER_ROLE = "operator" | "admin";

export interface User {
  firstName: string;
  lastName: string;
  patronymicName: string;
  email: string;
  password: string;
  role: USER_ROLE;
  avatarUrl: string;
}

export type AlertType = "ALL" | "ROUTES" | "STATIONS";

export interface Alert {
  id: uuid;
  version: number;
  cityId: string;
  text: LocalizedString;
  fontSize: number;
  bgColor: string; // hex RGB-color (e.g. #ffffff).
  icon?: { src: string };
  iconUrl?: string;
  order: number;
  binding: AlertAll | AlertRoute | AlertStation;
  isHidden: boolean;
}

interface AlertBase {
  type: AlertType;
}

interface AlertAll extends AlertBase {
  type: "ALL";
}

interface AlertRoute extends AlertBase {
  type: "ROUTES";
  routeIds: uuid[];
}

interface AlertStation extends AlertBase {
  type: "STATIONS";
  stationIds: uuid[];
}

export interface Tram {
  id: uuid;
  version: number;
  number: string;
  cityId: string;
  apiKey: string;
  autoDataUpdateDisabled: boolean;
}

export type ExportState = "SCHEDULED" | "IN_PROGRESS" | "DONE" | "SKIP";

export interface TramState {
  id: uuid;
  tramId: uuid;
  routeId?: uuid;
  state: string;
  coordinates: Coordinates;
  lastExport: {
    lastExportId: uuid;
    lastExportState: ExportState;
  };
  timestamp: string;
}

export type UpdateType = "ALL" | "TRAMS";

export interface Update {
  id: uuid;
  title: string;
  createTimestamp: number;
  exportBinding: UpdateAll | UpdateTrams;
}

interface UpdateBase {
  type: UpdateType;
}

interface UpdateAll extends UpdateBase {
  type: "ALL";
}

interface UpdateTrams extends UpdateBase {
  type: "TRAMS";
  tramIds: uuid[];
}

declare global {
  interface Window {
    restServer: any;
  }
}

// TODO: Rename with BE pointOnMap => coordinates
export interface Station extends Omit<StationOnMap, "coordinates"> {
  pointOnMap: Coordinates;
}

export interface Article extends Omit<ArticleBase, "name"> {
  title: LocalizedString;
}

export interface Transfer {
  type: TransportType;
  name: LocalizedString;
}

/**
 * TYPES
 */
export * from "./uuid.type";
export * from "./media.type";
export * from "./track.type";
export * from "./coordinates.type";
export * from "./on-map.type";
export * from "./transport.type";
export * from "./option.type";
export * from "./attraction-group-icon-size.type";
export * from "./order.type";
export * from "./set-state.type";

/**
 * INTERFACES
 */
export * from "./station.interface";
export * from "./attraction.interface";
export * from "./attraction-widget.interface";
export * from "./article.interface";
export * from "./lightbox.interface";
export * from "./station";
export * from "./constants";
