import {
  LongPollingQueryOptions,
  useLongPollingQuery,
} from "./useLongPollingQuery";

export type EventQueryData<T> = T & {
  ["@type"]: string;
};

const API_URL = "https://localhost:8443";

export function useEventQuery<T>(
  endpoint: string,
  eventNames: string[],
  options?: LongPollingQueryOptions<EventQueryData<T>[]>
) {
  const { pollingInterval = 0, maxRetries = 3 } = options || {};
  const queryKey = [endpoint, eventNames];

  return useLongPollingQuery<EventQueryData<T>[]>(
    queryKey,
    async () =>
      await fetch(`${API_URL}${endpoint}`)
        .then((res) => res.json())
        .then((data: EventQueryData<T>[]) =>
          data.filter((e) => eventNames.includes(e["@type"]))
        ),
    {
      pollingInterval,
      maxRetries,
    }
  );
}
