import { useRef, useState } from "react";
import { useCssProperty } from "./useCssProperty";

const getNumberPxFormatter = (numberStr: string | null) =>
  numberStr ? parseInt(numberStr) : 0;
const setNumberPxFormatter = (number: number) => `${number}px`;

export const useToggleScrollable = () => {
  const [isScrollBlocked, setIsScrollBlocked] = useState<boolean>(false);
  const { documentElement: html } = document;
  const htmlRef = useRef<HTMLElement>(html);

  const scrollBarWidthValue = useCssProperty<number>(
    "--scroll-bar-width",
    htmlRef,
    setNumberPxFormatter,
    getNumberPxFormatter
  );
  const horizontalScrollBarWidthValue = useCssProperty<number>(
    "--horizontal-scroll-bar-width",
    htmlRef,
    setNumberPxFormatter,
    getNumberPxFormatter
  );

  const disableScroll = () => {
    if (isScrollBlocked) return;

    scrollBarWidthValue.value = window.innerWidth - html.clientWidth;
    horizontalScrollBarWidthValue.value =
      window.innerHeight - html.clientHeight;
    html.classList.add("g-no-scroll");

    setIsScrollBlocked(true);
  };

  const enableScroll = () => {
    if (!isScrollBlocked) return;

    scrollBarWidthValue.value = 0;
    horizontalScrollBarWidthValue.value = 0;
    html.classList.remove("g-no-scroll");

    setIsScrollBlocked(false);
  };

  return { disableScroll, enableScroll };
};
