import React, { HTMLProps } from "react";
import { LoadingScreen } from "./LoadingScreen";

export class ErrorBoundary extends React.Component {
  state: { hasError: boolean };
  constructor(props: HTMLProps<HTMLDivElement>) {
    super(props);
    this.state = { hasError: false };
  }

  static getDerivedStateFromError() {
    // Update state so the next render will show the fallback UI.
    return { hasError: true };
  }

  componentDidCatch(error: Error) {
    setTimeout(() => window.location.reload(), 5000);
  }

  render() {
    if (this.state.hasError) {
      // You can render any custom fallback UI
      return <LoadingScreen />;
    }

    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    return this.props.children;
  }
}
