import { MapWidget, useMapWidgetContext } from "@mt/components";
import { useGetMapData } from "./useGetMapData";
import { EventQueryData, useEventQuery, useLoading } from "@mt/utils";
import { useEffect } from "react";
// TODO: resolve circular deps
import { Coordinates } from "@mt/common-types";

export const MapWidgetContainer = () => {
  const { isLoading } = useLoading();
  const { data, refetch } = useGetMapData();
  const { currentPosition, setCurrentPosition, onMapDataFetched } =
    useMapWidgetContext();

  const { data: events = [], isSuccess } = useEventQuery(
    "/widgets/route-map/events",
    ["REFRESH_DATA", "UPDATE_CURRENT_POINT_ON_TRACK"]
  );

  useEffect(() => {
    if (!data) {
      return;
    }

    onMapDataFetched(data);
  }, [data]);

  useEffect(() => {
    if (!isSuccess || !events.length) {
      return;
    }

    if (events.some((e) => e["@type"] === "REFRESH_DATA")) {
      refetch();

      return;
    }

    const { currentPointOnTrack } = events.at(-1) as EventQueryData<{
      currentPointOnTrack: Coordinates;
    }>;

    setCurrentPosition(currentPointOnTrack);
  }, [events, isSuccess, refetch]);

  if (isLoading || !data || !currentPosition) {
    return null;
  }

  return <MapWidget />;
};
