import { useEffect, useState } from "react";
import { useLongPollingQuery } from "@mt/utils";
import { WEATHER_DEFAULTS, WeatherWidgetData } from "@mt/components";

export const useWeatherData = () => {
  const [data, setData] = useState<WeatherWidgetData>(WEATHER_DEFAULTS);

  const { isSuccess, data: weatherData } = useLongPollingQuery<
    WeatherWidgetData,
    Error
  >(
    ["getWeatherData"],
    async () => {
      const response = await fetch(
        "https://localhost:8443/widgets/general-info/data"
      );

      return response.json();
    },
    {
      pollingInterval: 3000, // client-side delayed long-polling
      maxRetries: Number.MAX_SAFE_INTEGER,
    }
  );

  useEffect(() => {
    if (isSuccess && weatherData) {
      const { weatherInfo, forecasts } = weatherData;

      setData({
        weatherInfo,
        forecasts,
      });
    }
  }, [isSuccess, weatherData]);

  return { data };
};
