import { LocalizedString } from "@mt/i18n";
import { useEventQuery } from "@mt/utils";
import { useQuery } from "@tanstack/react-query";
import { UseQueryResult } from "@tanstack/react-query";
import { useEffect } from "react";

interface Attraction {
  id: string;
  name: LocalizedString;
  iconUrl: string;
}

export function useGetAttractionList(): UseQueryResult<Attraction[]> {
  const { data, isSuccess } = useEventQuery(
    "/widgets/attraction-with-details-list/events",
    ["REFRESH_DATA"]
  );

  const attractionListQuery = useQuery<Attraction[]>({
    queryKey: ["getAttractionList"], // Query keys should be an array
    queryFn: async () => {
      const response = await fetch(
        "https://localhost:8443/widgets/attraction-with-details-list/data"
      );
      if (!response.ok) {
        throw new Error("Network response was not ok");
      }
      const data = await response.json();
      return data.touristAttractions;
    },
    refetchOnWindowFocus: false,
    refetchOnMount: false,
  });

  useEffect(() => {
    if (isSuccess && data.length) {
      attractionListQuery.refetch();
    }
  }, [data, isSuccess]);

  return attractionListQuery;
}
