import styled from "@emotion/styled";
import { useState, useEffect } from "react";

const StyledDashboard = styled.div`
  background-color: #000;
  width: 100%;
  height: 100%;
  position: relative;
  overflow: hidden;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;

  .container {
    width: 100%;
    max-width: 960px;
    padding: 24px;
    box-sizing: border-box;
  }

  .video-wrapper {
    width: 100%;
    display: flex;
    justify-content: center;
    margin-top: 24px;
  }

  video {
    width: 100%;
    max-height: 80vh;
    border-radius: 12px;
    object-fit: cover;
  }

  .error {
    color: red;
    margin-top: 12px;
  }

  .loader {
    color: white;
    margin-top: 12px;
  }

  .upload {
    margin-top: 24px;
    color: white;

    input {
      margin-left: 12px;
    }
  }
`;

export function Dashboard() {
  const [videoUrl, setVideoUrl] = useState<string | undefined>();
  const [isLoading, setIsLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const fetchVideo = async () => {
      try {
        const response = await fetch(
          `https://wn.krbl.ru/media/981d44f9-85e7-4d1d-994b-9eab631ba5d1/download?token=${localStorage.getItem(
            "refine-auth"
          )}`
        ); // <-- укажи тут свой URL
        if (!response.ok) throw new Error("Не удалось загрузить видео");

        const blob = await response.blob();
        const objectUrl = URL.createObjectURL(blob);
        setVideoUrl(objectUrl);
        setIsLoading(false);
      } catch (err) {
        setError("Ошибка при загрузке видео");
        setIsLoading(false);
      }
    };

    fetchVideo();

    // Очистка при размонтировании
    return () => {
      if (videoUrl) {
        URL.revokeObjectURL(videoUrl);
      }
    };
  }, []);

  const handleFileUpload = (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0];
    if (file) {
      const objectUrl = URL.createObjectURL(file);
      setVideoUrl(objectUrl);
      setError(null);
      setIsLoading(false);
    }
  };

  return (
    <StyledDashboard>
      <div className="container">
        {isLoading && <div className="loader">Загрузка видео...</div>}
        {error && <div className="error">{error}</div>}

        {videoUrl && (
          <div className="video-wrapper">
            <video src={videoUrl} autoPlay controls muted />
          </div>
        )}
      </div>
    </StyledDashboard>
  );
}
