import { useEffect } from 'react';
import { Lightbox } from '@mt/components';
import { LoadingScreen, useLoading } from '@mt/utils';
import { useBackendStatus } from './useBackendStatus';
import { Dashboard } from '../dashboard/Dashboard';
import { useSplashScreenIsDisplayed } from './useSplashScreenStatus';

export function MainScreen() {
  const { isLoading, hideLoadingScreen, showLoadingScreen } = useLoading();
  const { backendStatus } = useBackendStatus();
  const { isSplashScreenDisplayed } = useSplashScreenIsDisplayed();

  useEffect(() => {
    if (backendStatus === 'UP' && !isSplashScreenDisplayed) {
      hideLoadingScreen();
    } else if (backendStatus === 'DOWN' || isSplashScreenDisplayed) {
      showLoadingScreen();
    }
  }, [
    backendStatus,
    isSplashScreenDisplayed,
    hideLoadingScreen,
    showLoadingScreen,
  ]);

  return isLoading ? (
    <LoadingScreen />
  ) : (
    <>
      <Dashboard />

      <Lightbox />
    </>
  );
}
