import { useEffect, useRef, useState } from 'react';
import { useLoading } from '@mt/utils';

type BE_STATUS = 'UP' | 'DOWN';
interface BackendHealthResponse {
  status: BE_STATUS;
}

export const useBackendStatus = () => {
  const [backendStatus, setBackendStatus] = useState<BE_STATUS>('DOWN');
  const timeoutRef = useRef<NodeJS.Timeout | null>(null);
  const { isLoading } = useLoading();

  useEffect(() => {
    const retry = () => {
      if (timeoutRef.current) {
        clearTimeout(timeoutRef.current);
      }

      timeoutRef.current = setTimeout(() => checkStatus(), 1000);
    };

    const checkStatus = async () => {
      await fetch('https://localhost:8443/_app/actuator/health')
        .then((response) => {
          if (!response.ok && response.status === 404) {
            retry();
          } else {
            return response.json();
          }
        })
        .then((data: BackendHealthResponse) => {
          if (data.status === 'UP') {
            setBackendStatus('UP');
          } else {
            setBackendStatus('DOWN');
            retry();
          }
        })
        .catch((error) => {
          setBackendStatus('DOWN');
          retry();
        });
    };

    if (isLoading) {
      checkStatus();
    }
  }, [isLoading]);

  return { backendStatus };
};
