import { useEffect, useState } from 'react';
import { EventQueryData, useEventQuery } from '@mt/utils';

export const useSplashScreenIsDisplayed = () => {
  const [isSplashScreenDisplayed, setIsSplashScreenDisplayed] =
    useState<boolean>();

  const { data: events, isSuccess } = useEventQuery(
    '/widgets/splash-screen/events',
    ['UPDATE_DISPLAYED_FLAG'],
    { maxRetries: Number.MAX_SAFE_INTEGER }
  );

  useEffect(() => {
    if (!isSuccess || !events.length) {
      return;
    }

    const { isDisplayed } = events.at(-1) as EventQueryData<{
      isDisplayed: boolean;
    }>;

    setIsSplashScreenDisplayed(isDisplayed);
  }, [isSuccess, events]);

  return { isSplashScreenDisplayed };
};
