import type { LocalizedString, LocalizeTextFn } from '@mt/i18n';

const meterLabel: LocalizedString = {
  ru: 'м',
  en: 'm',
  zh: '米',
};

const kilometerLabel: LocalizedString = {
  ru: 'км',
  en: 'km',
  zh: '公里',
};

export function getDistanceFormatter(
  localizeText: LocalizeTextFn
): (distance: number | undefined) => string {
  return (distance) => {
    if (!distance) {
      return '';
    }

    if (distance < 1000) {
      return `${distance} ${localizeText(meterLabel)}`;
    }

    return `${(distance / 1000).toFixed(2)} ${localizeText(kilometerLabel)}`;
  };
}
