import styled from '@emotion/styled';
import { AccordionDetails, AccordionSummary, accordionSummaryClasses } from '@mui/material';
import MuiAccordion, { accordionClasses } from '@mui/material/Accordion';

export const NavAccordion = styled(MuiAccordion)`
  box-shadow: none;
  background-color: transparent;
  color: #ffffff;

  &:before {
    content: '';
    display: none;
  }

  &.${accordionClasses.expanded} {
    margin: 0;
  }
  &.${accordionClasses.disabled} {
    background-color: transparent;
  }
`;

export const NavAccordionSummary = styled(AccordionSummary)`
  pointer-events: none;
  border-bottom: 1px solid #a6a6a6;
  padding: 8px 16px;
  line-height: 24px;
  margin-top: 8px;

  .${accordionSummaryClasses.content} {
    margin: 0;
    width: 100%;
  }
  &.${accordionSummaryClasses.expanded} {
    min-height: 0;
    .${accordionSummaryClasses.content} {
      margin: 0;
    }
  }

  &.${accordionSummaryClasses.disabled} {
    opacity: 1;
  }
`;

export const NavAccordionDetails = styled(AccordionDetails)`
  padding: 12px 16px;
  background: linear-gradient(90.36deg, #4e351f 0.27%, #59422d 47.89%, #65503c 99.65%);
`;

export const StyledNavWidget = styled.div`
  height: 100%;
  transition: all ease-in-out 0.3s;

  &:has(.tab-container--opened) {
    background: linear-gradient(180deg, rgba(255, 255, 255, 0.2) 0%, rgba(255, 255, 255, 0) 100%),
      rgba(128, 108, 89, 0.4);
  }

  .tab-button {
    display: block;
    padding: 8px 16px;
    background: #ffffff;
    color: #000;
    margin: 12px 30px;
    width: calc(100% - 60px);
    border-radius: 10px;
  }

  .slogan {
    font-style: italic;
    font-weight: 400;
    font-size: 16px;
    line-height: 150%;
    margin-top: 35px;
  }

  .hashtag {
    margin-top: 180px;
    margin-bottom: 32px;
  }

  .tab-container {
    transform: translateY(100%);
    height: calc(100% - 250px);
    width: 100%;
    transition: all ease-in-out 0.3s;
    position: absolute;
    bottom: 0;

    background: linear-gradient(
        113.51deg,
        rgba(255, 255, 255, 0) 8.71%,
        rgba(255, 255, 255, 0.16) 69.69%
      ),
      #806c59;
    box-shadow: 0 4px 4px rgba(0, 0, 0, 0.25);
    border-radius: 10px 10px 0 0;

    &.tab-container--opened {
      transform: translateY(0);
      filter: drop-shadow(0px -6px 13px rgba(0, 0, 0, 0.25));
    }
  }

  .tab-title {
    text-align: center;
    font-weight: 700;
    font-size: 16px;
    line-height: 24px;
    border-bottom: 1px solid #ffffff;
    padding-top: 13px;
    padding-bottom: 9px;
    background: linear-gradient(
        114deg,
        rgba(255, 255, 255, 0) 8.71%,
        rgba(255, 255, 255, 0.16) 69.69%
      ),
      #806c59;
    position: relative;
    &:before {
      content: '';
      width: 98px;
      height: 4px;
      border-radius: 0 0 4px 4px;
      background: #a6a6a6;
      opacity: 0.35;
      position: absolute;
      top: 0;
      left: 50%;
      transform: translateX(-50%);
    }
  }

  .tab-list__item {
    position: relative;
  }
  .tab-list__item-expander {
    position: absolute;
    top: -8px;
    left: 0;
    width: 100%;
    height: 55px;
    z-index: 1;
    cursor: pointer;
  }
  .tab-list__item-label {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    text-align: left;
    display: block;
  }
  .tab-list__item-card {
    padding: 12px 0;
  }

  .stop__icon {
    margin-right: 8px;
    width: 18px;
  }

  .distance {
    font-size: 12px;
    color: #d9d9d9;
    margin-left: 5px;
    line-height: 185%;
  }
`;
