import React, { useEffect, useState } from 'react';
import { Icons, TransportIcon } from '@mt/components';
import './OperativeInfoWidget.css';
import { useOperativeInfo } from './useOperativeInfo';
import { FormattedMessage } from 'react-intl';
import { useServerLocalization } from '@mt/i18n';
import { AlertMessage } from './alert.interface';
import { TransferItem } from './transfer.interface';

export function OperativeInfoWidget() {
  const [isOpen, setIsOpen] = useState<boolean>(false);
  const { transfers, alerts } = useOperativeInfo();

  useEffect(() => {
    setIsOpen(transfers.length > 0 || alerts.length > 0);
  }, [transfers, alerts]);

  return (
    <div className="operative-info-widget">
      <button className="info-btn" onPointerUp={() => setIsOpen(!isOpen)}>
        <Icons.InfoBtn />
      </button>

      {isOpen && (
        <div className="popup">
          <AlertsList alerts={alerts} />
          <TransfersList transfers={transfers} />
        </div>
      )}
    </div>
  );
}

function AlertsList({ alerts }: { alerts: AlertMessage[] }) {
  const localizeText = useServerLocalization();

  return alerts.length ? (
    <ul className="alerts-list">
      {alerts.map(({ key, bgColor, fontSize, iconUrl, text }) => (
        <li
          className="alert-list-item"
          key={key}
          style={{ backgroundColor: bgColor, fontSize: fontSize }}
        >
          <span className="alert-name">
            {iconUrl && <img src={iconUrl} alt="" className="alert-icon" />}
            {localizeText(text)}
          </span>
        </li>
      ))}
    </ul>
  ) : null;
}

function TransfersList({ transfers }: { transfers: TransferItem[] }) {
  return transfers.length ? (
    <>
      <div className="popup-title">
        <FormattedMessage id="available-transfers" />
      </div>

      <ul className="transfers-list">
        {transfers.map(({ type, label }) => (
          <li className="transfer-list-item" key={type + label}>
            <TransportIcon className="transfer-type-icon" type={type} />

            <span className="transfer-name">{label}</span>
          </li>
        ))}
      </ul>
    </>
  ) : null;
}
