import dataProvider from "@refinedev/simple-rest";
import axios, { InternalAxiosRequestConfig } from "axios";

import { TOKEN_KEY } from "../authProvider";
import Cookies from "js-cookie";

interface CustomAxiosRequestConfig extends InternalAxiosRequestConfig {
  meta?: {
    headers?: {
      "X-Language"?: string;
    };
  };
}

export const axiosInstance = axios.create({
  baseURL: import.meta.env.VITE_KRBL_API,
});

axiosInstance.interceptors.request.use((config: CustomAxiosRequestConfig) => {
  // Добавляем токен авторизации
  const token = localStorage.getItem(TOKEN_KEY);
  if (token) {
    config.headers.Authorization = `Bearer ${token}`;
  }

  // Добавляем язык в кастомный заголовок
  const metaLang = config.meta?.headers?.["X-Language"];
  if (metaLang) {
    console.log("metaLang", metaLang);
    config.headers["X-Language"] = metaLang;
  } else {
    const lang = Cookies.get("lang") || "ru";
    console.log("lang", lang);
    config.headers["X-Language"] = lang;
  }
  // console.log('Request headers:', config.headers)

  return config;
});

const apiUrl = import.meta.env.VITE_KRBL_API;

export const customDataProvider = dataProvider(apiUrl, axiosInstance);
